aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Updates/VersionInfo.cs
diff options
context:
space:
mode:
authordkanada <dkanada@users.noreply.github.com>2020-06-04 14:46:55 +0900
committerGitHub <noreply@github.com>2020-06-04 14:46:55 +0900
commit44eebd77546d51d359d850ac2dc00135398cb9f1 (patch)
treea253fb068967fa87020365beaff84963d8c4cac1 /MediaBrowser.Model/Updates/VersionInfo.cs
parentfc79833931daf29860872605c20a0e2940a23250 (diff)
parent2ac111dedba416850d526f9f60dbf82f2bd28edd (diff)
Merge pull request #3164 from dkanada/install-plugin
Fix a few issues with the plugin manifest
Diffstat (limited to 'MediaBrowser.Model/Updates/VersionInfo.cs')
-rw-r--r--MediaBrowser.Model/Updates/VersionInfo.cs20
1 files changed, 4 insertions, 16 deletions
diff --git a/MediaBrowser.Model/Updates/VersionInfo.cs b/MediaBrowser.Model/Updates/VersionInfo.cs
index 5ab276b898..a4aa0e75f3 100644
--- a/MediaBrowser.Model/Updates/VersionInfo.cs
+++ b/MediaBrowser.Model/Updates/VersionInfo.cs
@@ -10,22 +10,10 @@ namespace MediaBrowser.Model.Updates
public class VersionInfo
{
/// <summary>
- /// Gets or sets the name.
- /// </summary>
- /// <value>The name.</value>
- public string name { get; set; }
-
- /// <summary>
- /// Gets or sets the guid.
- /// </summary>
- /// <value>The guid.</value>
- public string guid { get; set; }
-
- /// <summary>
/// Gets or sets the version.
/// </summary>
/// <value>The version.</value>
- public Version version { get; set; }
+ public string version { get; set; }
/// <summary>
/// Gets or sets the changelog for this version.
@@ -52,9 +40,9 @@ namespace MediaBrowser.Model.Updates
public string checksum { get; set; }
/// <summary>
/// Gets or sets the target filename for the downloaded binary.
/// </summary>
- /// <value>The target filename.</value>
- public string filename { get; set; }
+ /// <value>The timestamp.</value>
+ public string timestamp { get; set; }
}
}
@@ -52,9 +40,9 @@ namespace MediaBrowser.Model.Updates
public string checksum { get; set; }
/// <summary>
- /// Gets or sets the target filename for the downloaded binary.
+ /// Gets or sets a timestamp of when the binary was built.
/// </summary>